@@ -10,7 +10,7 @@ import matplotlib.lines as mlines
 import matplotlib.pyplot as plt
 from datetime import datetime, timedelta, time
 import argparse
-from accelerometer import accUtils
+from accelerometer import utils
 import matplotlib
 matplotlib.use('Agg')
 
@@ -61,7 +61,7 @@ def main():  # noqa: C901
     if len(sys.argv) < 2:
         msg = "\nInvalid input, please enter at least 1 parameter, e.g."
         msg += "\npython accPlot.py timeSeries.csv.gz \n"
-        accUtils.toScreen(msg)
+        utils.toScreen(msg)
         parser.print_help()
         sys.exit(-1)
     args = parser.parse_args()
@@ -102,15 +102,11 @@ def plotTimeSeries(  # noqa: C901
     # read time series file to pandas DataFrame
     data = pd.read_csv(
         tsFile, index_col='time',
-        parse_dates=['time'], date_parser=accUtils.date_parser
+        parse_dates=['time'], date_parser=utils.date_parser
     )
     if showFirstNDays is not None:
         data = data.first(str(showFirstNDays) + 'D')
 
-    # smoothing & normalize
-    data['acc'] = data['acc'].rolling(window=12, min_periods=1).mean()
-    data['acc'] /= data['acc'].max()
-
     labels = [label for label in LABELS_AND_COLORS.keys() if label in data.columns]
     colors = [LABELS_AND_COLORS[label] for label in labels]
 
@@ -120,6 +116,12 @@ def plotTimeSeries(  # noqa: C901
         data.loc[mask, labels_excl_imputed] = 0
         data.loc[mask, "acc"] = np.nan
 
+    # setup plotting range
+    MAXRANGE = 2 * 1000  # 2g (above this is very rare)
+    data['acc'] = data['acc'].rolling('1T').mean()  # minute average
+    data['acc'] = data['acc'].clip(0, MAXRANGE)
+    data[labels] = data[labels].astype('f4') * MAXRANGE
+
     # number of rows to display in figure (all days + legend)
     data.index = data.index.tz_localize(None, ambiguous='NaT', nonexistent='NaT')  # tz-unaware local time
     groupedDays = data.groupby(data.index.date)
@@ -141,7 +143,7 @@ def plotTimeSeries(  # noqa: C901
 
         if len(labels) > 0:
             ax.stackplot(group.index,
-                         group[labels].astype('f4').to_numpy().T,
+                         group[labels].to_numpy().T,
                          colors=colors,
                          edgecolor="none")
 
@@ -167,7 +169,7 @@ def plotTimeSeries(  # noqa: C901
         ax.set_xticks(pd.date_range(start=datetime.combine(day, time(0, 0, 0, 0)),
                                     end=datetime.combine(day + timedelta(days=1), time(0, 0, 0, 0)),
                                     freq='1H'), minor=True)
-        ax.set_ylim(0, 1)
+        ax.set_ylim(0, MAXRANGE)
         ax.get_yaxis().set_ticks([])  # hide y-axis lables
         # make border less harsh between subplots
         ax.spines['top'].set_color('#d3d3d3')  # lightgray
