@@ -7,16 +7,28 @@ MODEL_DIR_URL = "http://gas.ndph.ox.ac.uk/aidend/accModels/"
 
 MODELS = {
     'willetts': {
-        "pth": MODEL_DIR / "willetts-jan21.tar",
-        "url": MODEL_DIR_URL + "willetts-jan21.tar",
+        "pth": MODEL_DIR / "willetts-jan22.tar",
+        "url": MODEL_DIR_URL + "willetts-jan22.tar",
     },
     'doherty': {
-        "pth": MODEL_DIR / "doherty-jan21.tar",
-        "url": MODEL_DIR_URL + "doherty-jan21.tar",
+        "pth": MODEL_DIR / "doherty-jan22.tar",
+        "url": MODEL_DIR_URL + "doherty-jan22.tar",
     },
     'walmsley': {
-        "pth": MODEL_DIR / "walmsley-jan21.tar",
-        "url": MODEL_DIR_URL + "walmsley-jan21.tar",
+        "pth": MODEL_DIR / "walmsley-jan22.tar",
+        "url": MODEL_DIR_URL + "walmsley-jan22.tar",
+    },
+    'willetts-jan22': {
+        "pth": MODEL_DIR / "willetts-jan22.tar",
+        "url": MODEL_DIR_URL + "willetts-jan22.tar",
+    },
+    'doherty-jan22': {
+        "pth": MODEL_DIR / "doherty-jan22.tar",
+        "url": MODEL_DIR_URL + "doherty-jan22.tar",
+    },
+    'walmsley-jan22': {
+        "pth": MODEL_DIR / "walmsley-jan22.tar",
+        "url": MODEL_DIR_URL + "walmsley-jan22.tar",
     },
     'willetts-jan21': {
         "pth": MODEL_DIR / "willetts-jan21.tar",
